{ pkgs, lib, ... }:

{
  imports = [
    # GUI
    ../../modules/home/gui/common
    ../../modules/home/gui/hyprland
    ../../modules/home/gui/nextcloud.nix
    ../../modules/home/gui/theming.nix
    ../../modules/home/gui/thunderbird.nix

    # CLI
    ../../modules/home/cli/common
    ../../modules/home/cli/develop.nix
    ../../modules/home/cli/ssh.nix
    ../../modules/home/cli/yazi.nix
  ];


  options = {
    host = lib.mkOption {
      type = with lib.types; str;
      description = ''
        Define the host of the machine
      '';
    };

    headless = lib.mkOption {
      type = with lib.types; bool;
      description = ''
        Is this machine headless?
      '';
    };
  };

  config = {
    home = {
      username = "xeovalyte";
      homeDirectory = "/home/xeovalyte";
    };

    host = "xv-laptop";
    headless = false;

    home.packages = with pkgs; [
      # Desktop Applications
      kdenlive
      prismlauncher
      unstable.modrinth-app
      unstable.joplin-desktop
      unstable.prusa-slicer
      unstable.font-manager
      signal-desktop
      unstable.vesktop
      unstable.webcord
      blender
      unstable.freecad-wayland
      loupe
      unstable.rnote
      unstable.bottles


      # Office
      libreoffice

      # Image editing
      gimp
      inkscape
      unstable.obs-studio

      # Development
      unstable.drawio

      # Scripts
      (import ../../modules/scripts/save_image.nix { inherit pkgs; })
    ];

    # Enable home-manager
    programs.home-manager.enable = true;

    # Enable default applications
    xdg.mimeApps = {
      enable = true;
      defaultApplications = {
        "application/pdf" = "firefox.desktop";
        "application/rnote" = "rnote.desktop";
      };
    };

    home.stateVersion = "24.05";
  };

}
